# MistralAI Plugin for LiveKit Agents

Support for MistralAI LLM, ChatModels

See [https://docs.livekit.io/agents/integrations/mistral/](https://docs.livekit.io/agents/integrations/mistral/) for more information.

## Installation

```bash
pip install livekit-plugins-mistral
```

## Pre-requisites

You'll need an API key from MistralAI. It can be set as an environment variable:

```bash
export MISTRAL_API_KEY=your_api_key_here
```
